==> haskell-dotgen-0.4.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dotgen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dotgen
version:              0.4.2
visibility:           public
id:                   dotgen-0.4.2-3vjDpfIg3aaGS5vCVTeOwR
key:                  dotgen-0.4.2-3vjDpfIg3aaGS5vCVTeOwR
license:              BSD-3-Clause
maintainer:           Andy Gill <andygill@ku.edu>
author:               Andy Gill
stability:            alpha
homepage:             https://github.com/ku-fpg/dotgen
synopsis:             A simple interface for building .dot graph files.
description:
    This package provides a simple interface for building .dot graph files,
    for input into the dot and graphviz tools.
    It includes a monadic interface for building graphs.

category:             Text
abi:                  76f3e7f018e2674cfa8cc9c09c5efe93
exposed:              True
exposed-modules:      Text.Dot
import-dirs:          /usr/lib/ghc-8.8.3/site-local/dotgen-0.4.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/dotgen-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/dotgen-0.4.2
hs-libraries:         HSdotgen-0.4.2-3vjDpfIg3aaGS5vCVTeOwR
depends:              base-4.13.0.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-dotgen/html/dotgen.haddock
haddock-html:         /usr/share/doc/haskell-dotgen/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dotgen-0.4.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dotgen.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dotgen
version:              0.4.2
visibility:           public
id:                   dotgen-0.4.2-CoAss38fVXB3fwtMlSEDAi
key:                  dotgen-0.4.2-CoAss38fVXB3fwtMlSEDAi
license:              BSD-3-Clause
maintainer:           Andy Gill <andygill@ku.edu>
author:               Andy Gill
stability:            alpha
homepage:             https://github.com/ku-fpg/dotgen
synopsis:             A simple interface for building .dot graph files.
description:
    This package provides a simple interface for building .dot graph files,
    for input into the dot and graphviz tools.
    It includes a monadic interface for building graphs.

category:             Text
abi:                  5458c16a47777a41ebb49f7a88cee28e
exposed:              True
exposed-modules:      Text.Dot
import-dirs:          /usr/lib/ghc-8.10.1/site-local/dotgen-0.4.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/dotgen-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/dotgen-0.4.2
hs-libraries:         HSdotgen-0.4.2-CoAss38fVXB3fwtMlSEDAi
depends:              base-4.14.0.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-dotgen/html/dotgen.haddock
haddock-html:         /usr/share/doc/haskell-dotgen/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
